SuffaDateTimeInput class

Inheritance

Constructors

SuffaDateTimeInput({Key? key, required TextEditingController controller, dynamic onSubmit(String)?, dynamic onChanged(String)?, Color? onDoneColor, Color? onItemColor, required dynamic onConfirm(DateTime time), List<TextInputFormatter>? inputFormatter, FocusNode? focusNode, String? hintText, Color? onCancelColor, TextStyle? fontStyle})
const

Properties

controller TextEditingController
controller datetime input controller
final
focusNode FocusNode?
focusNode focus state
final
fontStyle TextStyle?
fontStyle font
final
hashCode int
The hash code for this object.
no setterinherited
hintText String?
hintText hint text
final
inputFormatter List<TextInputFormatter>?
inputFormatter input formatter
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCancelColor Color?
onCancelColor the colour of the "cancel" button at the top left when the picker comes out
final
onChanged → dynamic Function(String)?
onChanged function to run when the value changes
final
onConfirm → dynamic Function(DateTime time)
onConfirm function to run when date is selected
final
onDoneColor Color?
onDoneColor the colour of the "done" button at the top right of the picker
final
onItemColor Color?
onItemColor the colour of the dates when the picker comes out
final
onSubmit → dynamic Function(String)?
onSubmit they will work when you press the submit button on the keyboard
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<SuffaDateTimeInput>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited